@@ -27,8 +27,11 @@ class Database_Notes
   private static $instance;
   private $standard_statuses = array ("New", "Pending", "In progress", "Done", "Reopened");
   private $standard_severities = array (0 => "Wish", 1 => "Minor", 2 => "Normal", 3 => "Important", 4 => "Major", 5 => "Critical");
-  private function __construct() {
+
+  private function __construct() 
+  {
   } 
+
   public static function getInstance() 
   {
     if ( empty( self::$instance ) ) {
@@ -200,6 +203,7 @@ EOD;
   * If $limit is non-NULL, it indicates the starting limit for the selection.
   * $book, $chapter, $verse, $passage_selector: These are related and can limit the selection.
   * $edit_selector: Optionally constrains selection based on modification time.
+  * $non_edit_selector: Optionally constrains selection based on modification time.
   * $status_selector: Optionally constrains selection based on note status.
   * $bible_selector: Optionally constrains the selection, based on the note's Bible.
   * $assignment_selector: Optionally constrains the selection based on a note being assigned to somebody.
@@ -209,7 +213,7 @@ EOD;
   * $search_text: Works with $text_selector, contains the text to search for.
   * $userlevel: if 0, it takes the user's level from the current user, else it takes the level passed in the variable $userlevel itself.
   */
-  public function selectNotes ($bible, $book, $chapter, $verse, $passage_selector, $edit_selector, $status_selector, $bible_selector, $assignment_selector, $subscription_selector, $severity_selector, $text_selector, $search_text, $limit, $userlevel)
+  public function selectNotes ($bible, $book, $chapter, $verse, $passage_selector, $edit_selector, $non_edit_selector, $status_selector, $bible_selector, $assignment_selector, $subscription_selector, $severity_selector, $text_selector, $search_text, $limit, $userlevel)
   {
     $session_logic = Session_Logic::getInstance ();
     if ($userlevel == 0)  $userlevel = $session_logic->currentLevel ();
@@ -266,6 +270,30 @@ EOD;
         break;
     }
     if ($time != 0) $query .= " AND modified >= $time ";
+    // Consider non-edit selector.
+    switch ($non_edit_selector) {
+      case 0:
+        // Select notes that have not been edited: Do not care. Apply no constraint.
+        $nonedit = 0;
+        break;
+      case 1:
+        // Select notes that have not been edited for the last 30 days.
+        $nonedit = strtotime ("today -30 days");
+        break;
+      case 2:
+        // Select notes that have not been edited for the last 7 days.
+        $nonedit = strtotime ("today -7 days");
+        break;
+      case 3:
+        // Select notes that have not been edited since yesterday.
+        $nonedit = strtotime ("yesterday");
+        break;
+      case 4:
+        // Select notes that have not been edited today.
+        $nonedit = strtotime ("today");
+        break;
+    }
+    if ($nonedit != 0) $query .= " AND modified <= $nonedit ";
     // Consider status constraint.
     if ($status_selector != "") {
       $query .= " AND status = '$status_selector' ";
@@ -294,7 +322,7 @@ EOD;
       $query .= " AND (MATCH (summary, contents) AGAINST ('$search_text' IN BOOLEAN MODE) OR summary LIKE '%$search_text%' OR CONTENTS LIKE '%$search_text%') ";
     }
     // Notes get ordered by the passage they refer to. It is a rough method and better ordering is needed. 
-    $query .= " ORDER BY passage ";
+    $query .= " ORDER BY ABS(passage) ";
     // Limit the selection if a limit is given.
     if (is_numeric ($limit)) {
       $limit = Database_SQLInjection::no ($limit);
