@@ -11,8 +11,8 @@ class Filter_Backup
     if ($value == "") {
       return $value;
     }
-    $file = dirname (dirname (__FILE__));
-    $file = $file . "/" . $value . ".sql.gz";
+    include ("paths/paths.php");
+    $file = $localStatePath . "/" . $value . ".sql.gz";
     return $file;
   }
   
@@ -28,10 +28,6 @@ class Filter_Backup
     $url = $url . "/" . $value . ".sql.gz";
     return $url;
   }
-  
-  
-  
-  
     
 
 }
