@@ -394,7 +394,8 @@ EOD;
   */
   public function git_directory ($object)
   {
-    $directory = dirname (dirname (__FILE__));
+    include ("paths/paths.php");
+    $directory = $localStatePath;
     $directory = "$directory/git/$object";
     return $directory;
   }
@@ -407,9 +408,7 @@ EOD;
       $entry = $database_git->get ();
       $directory = $entry['directory'];
       $output = $entry['output'];
-      $path = dirname (dirname (__FILE__));
-      $path = "$path/git/";
-      $object = substr ($directory, strlen ($path));
+      $object = basename ($directory);
       if ($object == "consultationnotes") {
         Filter_Git::notesFiledata2database ($directory, $output);
       } else {
