@@ -37,66 +37,34 @@ $database_users = Database_Users::getInstance();
 $database_mail = Database_Mail::getInstance();
 $database_bibles = Database_Bibles::getInstance ();
 
-$siteUrl = $database_config_general->getSiteURL ();
+include ("paths/paths.php");
 
 $bibles = $database_bibles->getDiffBibles ();
 foreach ($bibles as $bible) {
 
-  // Files get stored in http://site.org/bibledit/downloads/changes/<Bible>/<date>
-  // The user can access the files through the browser.
+  // The files get stored at http://site.org/bibledit-web/downloads/changes/<Bible>/<date>
   $biblename = $database_bibles->getName ($bible);
-  $baseUrl = "/downloads/changes/" . $biblename . "/" . strftime ("%Y-%m-%d_%H:%M:%S");
-  $directory = dirname (dirname (__FILE__)) . $baseUrl;
+  $basePath  = "/changes/" . $biblename . "/" . strftime ("%Y-%m-%d_%H:%M:%S");
+  $directory = $localStatePath . $basePath;
   mkdir ($directory, 0777, true);
   
-  // Remove possible old symbolic link.
+  // Remove old symbolic link if it's there.
   $link = dirname ($directory) . "/0_most_recent_changes";
   @unlink ($link);
-  //symlink ($directory, $link);
   
   // Produce the USFM and html files.
-  Filter_Diff::produceUsfmChapterLevel ($bible, $directory);
   Filter_Diff::produceVerseLevel ($bible, $directory);
   
   // Delete diff data for this Bible, allowing new diffs to be stored straightaway.
   $database_bibles->deleteDiffBible ($bible);
 
-  // Prepare for Daisy Diff.
-  Filter_Diff::copyDaisyDiffLibraries ($directory);
-
-  // Create online page showing changed verses.
+  // Create online page with changed verses.
   $versesoutputfile = "$directory/changed_verses.html";
-  Filter_Diff::runDaisyDiff ("$directory/verses_old.html", "$directory/verses_new.html", $versesoutputfile);
-  Filter_Diff::setDaisyDiffTitle ($versesoutputfile, $biblename, gettext ("recent changes"));
-
-  // Create online page showing changed chapters.
-  $chaptersoutputfile = "$directory/changed_chapters.html";
-  Filter_Diff::runDaisyDiff ("$directory/chapters_old.html", "$directory/chapters_new.html", $chaptersoutputfile);
-  Filter_Diff::setDaisyDiffTitle ($chaptersoutputfile, $biblename, gettext ("recent changes"));
-  
-  // Insert links to the online versions.
-  $links = array ();
-  $links [] = array ("", "View this online:");
-  $links [] = array ("$siteUrl$baseUrl/changed_verses.html", "changed verses");
-  $links [] = array ("", "|");
-  $links [] = array ("$siteUrl$baseUrl/changed_chapters.html", "changed chapters");
-  $links [] = array ("", "|");
-  $links [] = array ("$siteUrl$baseUrl/changed_verses_email.html", "emailed version");
-  Filter_Diff::insertLinks ("$directory/changed_verses.html", $links);
-  Filter_Diff::insertLinks ("$directory/changed_chapters.html", $links);
-  
-  // Copy the changed verses to the email file.
-  $emailoutputfile = "$directory/changed_verses_email.html";
-  file_put_contents ($emailoutputfile, file_get_contents ($versesoutputfile));
-  Filter_Diff::setDaisyDiffTitle ($emailoutputfile, $biblename, gettext ("recent changes"));
-  Filter_Diff::setDaisyDiffSubtitle ($emailoutputfile, gettext ("Added text shows in bold and light green. Removed text is stroked out and light red."));
-  Filter_Diff::integrateDaisyDiffStylesheet ($emailoutputfile, true);
-  Filter_Diff::removeDaisyDiffJavascript ($emailoutputfile);
-  Filter_Diff::removeDaisyDiffArrows ($emailoutputfile);
+  Filter_Diff::runWDiff ("$directory/verses_old.html", "$directory/verses_new.html", $versesoutputfile);
 
   // Email users.
   $subject = gettext ("Recent changes") . " " . $biblename;
-  $emailBody = file_get_contents ($emailoutputfile);
+  $emailBody = file_get_contents ($versesoutputfile);
   $users = $database_users->getUsers ();
   foreach ($users as $user) {
     if ($database_config_user->getUserBibleChangesNotification ($user)) {
